# Reel Caption Maker - Création de sous-titres pour Reels

Reel Caption Maker est un outil pour ajouter des sous-titres aux reels Instagram. Ce guide vous aidera à configurer et à exécuter l'application, même si vous n'êtes pas développeur.

## Prérequis

Avant de commencer, assurez-vous d'avoir installé les éléments suivants sur votre ordinateur :

1. Python 3.12 ou plus récent : Téléchargez depuis [python.org](https://www.python.org/downloads/)
2. Git : Téléchargez depuis [git-scm.com](https://git-scm.com/downloads)

## Étapes d'installation

1. Ouvrez le terminal ou l'invite de commande de votre ordinateur.

2. Clonez le dépôt :
   ```
   git clone https://github.com/votrenomdutilisateur/reel-caption-maker.git
   cd reel-caption-maker
   ```
### Utilisation de Python en local

3. Créez un environnement virtuel :
- Sur Windows :
  ```
  python -m venv venv
  venv\Scripts\activate
  ```
- Sur macOS et Linux :
  ```
  python3 -m venv venv
  source venv/bin/activate
  ```
  
4. Installez les packages requis :
  ```
  pip install -r requirements.txt
  ```
## Lancement de l'application

1. Assurez-vous d'être dans le répertoire du projet et que votre environnement virtuel est activé.

2. Démarrez l'application Streamlit :
   ```
   streamlit run app.py
   ```

3. Votre navigateur web par défaut devrait s'ouvrir automatiquement. Si ce n'est pas le cas, copiez l'URL affichée dans le terminal (généralement http://localhost:8501) et collez-la dans votre navigateur.

### Utilisation de Docker

Pour exécuter Reel Caption Maker avec Docker, suivez ces étapes :

1. Assurez-vous d'avoir Docker installé sur votre système.
2. Si ce n'est pas le cas, vous pouvez le télécharger et l'installer depuis [le site officiel de Docker](https://www.docker.com/get-started).
3. Construisez l'image Docker :
   ```
   docker build -t reel-caption-maker .
   ```
   
4. Exécutez le conteneur Docker :
   ```
   docker run -p 8501:8501 -v whisper_model:/root/.cache/huggingface reel-caption-maker
   ```
   Cette commande fait ce qui suit :
   - Mappe le port 8501 du conteneur au port 8501 de votre machine hôte.
   - Crée un volume nommé `whisper_model` pour persister les données du modèle Whisper.

5. Ouvrez votre navigateur web et accédez à `http://localhost:8501` pour utiliser Reel Caption Maker.
- Note : La première fois que vous exécutez le conteneur, cela peut prendre quelques minutes pour télécharger le modèle Whisper. Les exécutions suivantes seront plus rapides car le modèle sera mis en cache dans le volume Docker.
- Pour arrêter le conteneur, utilisez `Ctrl+C` dans le terminal où il s'exécute.
- Pour plus de commodité, vous pouvez utiliser le script `docker-run.sh` fourni pour démarrer le conteneur :
   ```
  chmod +x docker-run.sh
  ./docker-run.sh
   ```

## Utilisation de Reel Caption Maker

1. Cliquez sur "Browse files" pour télécharger votre vidéo.
2. Sélectionnez la langue de la vidéo (français ou anglais).
3. Cliquez sur "Generate Captions" pour transcrire l'audio.
4. Modifiez les sous-titres générés si nécessaire.
5. Cliquez sur "Burn Captions and Download" pour ajouter les sous-titres à votre vidéo et la télécharger.

## Dépannage

- Si vous rencontrez des erreurs, assurez-vous d'avoir suivi correctement toutes les étapes.
- Vérifiez que votre environnement virtuel est activé lors de l'exécution de l'application.
- Si vous avez toujours des problèmes, essayez de fermer le terminal, de le rouvrir et de recommencer à partir de l'étape 3 des étapes d'installation.

## Fermeture de l'application

Pour arrêter l'application, appuyez sur Ctrl+C dans le terminal où l'application s'exécute.

N'oubliez pas de désactiver l'environnement virtuel lorsque vous avez terminé :
deactivate

Profitez de l'utilisation de Reel Caption Maker !